@@ -99,6 +99,7 @@ for my $l (@listen) {
 		IMP_ACCTFIELD,
 		IMP_PAUSE,
 		IMP_CONTINUE,
+		IMP_FATAL,
 	    ],
 	]);
 
@@ -594,6 +595,13 @@ sub new {
 		&$close;
 		return;
 
+	    } elsif ( $rtype == IMP_FATAL ) {
+		my $reason = shift;
+		# FIXME use smthg better then just debug
+		$self->xdebug("fatal error from analyzer: $reason");
+		&$close;
+		return;
+
 	    } elsif ( $rtype == IMP_LOG ) {
 		my ($dir,$offset,$len,$level,$msg) = @$rv;
 		# FIXME use smthg better then just debug
